==> jc-1.4.0.tar.gz: polyglot/ext/jl/types/UnknownQualifier__5fc.h <==
// public class polyglot.ext.jl.types.UnknownQualifier_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d130bd574566704f polyglot_ext_jl_types_TypeObject__5fc
// @dep_class 606ff78c2f8b8966 polyglot_ext_jl_types_UnknownQualifier__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_types_TypeObject__5fc

#include "polyglot/ext/jl/types/TypeObject__5fc.h"

#ifndef _JC_polyglot_ext_jl_types_UnknownQualifier__5fc_H_
#define _JC_polyglot_ext_jl_types_UnknownQualifier__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Package$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$isCanonical$a799dea5db41ebc5(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
extern jboolean _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$isPackage$8548bf38c6ad3984(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
extern jboolean _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$isType$74fdff6263843afc(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$toPackage$41314d952443fa1f(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
extern struct _jc_object *_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$toType$4dd5ac4b101dcd1f(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$isCanonical$a799dea5db41ebc5;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$isPackage$8548bf38c6ad3984;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$isType$74fdff6263843afc;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$toPackage$41314d952443fa1f;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$toType$4dd5ac4b101dcd1f;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods {
	jboolean	(*isCanonical$a799dea5db41ebc5)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
	jboolean	(*isPackage$8548bf38c6ad3984)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
	jboolean	(*isType$74fdff6263843afc)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
	struct _jc_object	*(*toPackage$41314d952443fa1f)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
	struct _jc_object	*(*toType$4dd5ac4b101dcd1f)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *);
};

// Vtable
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeObject__5fc$vmethods	polyglot_ext_jl_types_TypeObject__5fc;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods	polyglot_ext_jl_types_UnknownQualifier__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs {
    _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs	polyglot_ext_jl_types_UnknownQualifier__5fc;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_refs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs	polyglot_ext_jl_types_UnknownQualifier__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object {
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_UnknownQualifier__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_UnknownQualifier__5fc_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/jl/types/UnknownQualifier__5fc.h <==
// public class polyglot.ext.jl.types.UnknownQualifier_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d130bd574566704f polyglot_ext_jl_types_TypeObject__5fc
// @dep_class 606ff78c2f8b8966 polyglot_ext_jl_types_UnknownQualifier__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_types_TypeObject__5fc

#include "polyglot/ext/jl/types/TypeObject__5fc.h"

#ifndef _JC_polyglot_ext_jl_types_UnknownQualifier__5fc_H_
#define _JC_polyglot_ext_jl_types_UnknownQualifier__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_types_Package$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_types_TypeSystem$object;

// Typedefs
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs;
typedef struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object;

typedef const struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods;
typedef const struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable;
typedef const struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype;

// Constructors
extern void _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$_init$964314195388e7c0(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$isCanonical$a799dea5db41ebc5(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$isPackage$8548bf38c6ad3984(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$isType$74fdff6263843afc(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$toPackage$41314d952443fa1f(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method$toType$4dd5ac4b101dcd1f(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$isCanonical$a799dea5db41ebc5;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$isPackage$8548bf38c6ad3984;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$isType$74fdff6263843afc;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$toPackage$41314d952443fa1f;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$toString$7ea43b33b80a3070;
extern _jc_method _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$method_info$toType$4dd5ac4b101dcd1f;

// Virtual methods structure
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods {
	jboolean	(*isCanonical$a799dea5db41ebc5)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
	jboolean	(*isPackage$8548bf38c6ad3984)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
	jboolean	(*isType$74fdff6263843afc)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toPackage$41314d952443fa1f)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*toType$4dd5ac4b101dcd1f)(_jc_env *, struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeObject__5fc$vmethods	polyglot_ext_jl_types_TypeObject__5fc;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vmethods	polyglot_ext_jl_types_UnknownQualifier__5fc;
};

// Vtype
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype {
	_jc_type			type;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs {
    _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_refs	polyglot_ext_jl_types_UnknownQualifier__5fc;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_refs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeObject__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeObject__5fc;
    _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$sub_nonrefs	polyglot_ext_jl_types_UnknownQualifier__5fc;
};

// Object instance structure
struct _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$object {
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype	*vtype;
	_jc_polyglot_ext_jl_types_UnknownQualifier__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$vtype _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_jl_types_UnknownQualifier__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_jl_types_UnknownQualifier__5fc$class_object;

#endif	/* _JC_polyglot_ext_jl_types_UnknownQualifier__5fc_H_ */
